==> openturns_1.5.orig.tar.bz2: openturns-1.5/lib/test/t_InverseMarginalTransformationHessian_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_InverseMarginalTransformationHessian_std.cxx
 *  @brief The test file of class InverseMarginalTransformationHessian for standard methods
 *
 *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author dutka
 *  @date   2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    InverseMarginalTransformationHessian::DistributionCollection coll(0);
    coll.add(Normal(1.0, 2.5));
    coll.add(Gamma(1.5, 3.0));
    InverseMarginalTransformationHessian transformation(coll);
    fullprint << "transformation=" << transformation << std::endl;
    NumericalPoint point(coll.getSize(), 0.75);
    fullprint << "transformation(" << point << ")=" << transformation.hessian(point) << std::endl;
    fullprint << "input dimension=" << transformation.getInputDimension() << std::endl;
    fullprint << "output dimension=" << transformation.getOutputDimension() << std::endl;
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.11.orig.tar.bz2: openturns-1.11/lib/test/t_InverseMarginalTransformationHessian_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @brief The test file of class InverseMarginalTransformationHessian for standard methods
 *
 *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#include "openturns/OT.hxx"
#include "openturns/OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    InverseMarginalTransformationHessian::DistributionCollection coll(0);
    coll.add(Normal(1.0, 2.5));
    coll.add(Gamma(1.5, 3.0));
    InverseMarginalTransformationHessian transformation(coll);
    fullprint << "transformation=" << transformation << std::endl;
    Point point(coll.getSize(), 0.75);
    fullprint << "transformation(" << point << ")=" << transformation.hessian(point) << std::endl;
    fullprint << "input dimension=" << transformation.getInputDimension() << std::endl;
    fullprint << "output dimension=" << transformation.getOutputDimension() << std::endl;
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
